//////////////////////////////////////////////////////////////////////////////////
// Module	 : App2600.h														//
// Function  : Header file for Sensoray 2600 applications						//
// Target OS : None -- OS independent											//
// Usage	 : Included by all apps using 2600 boards							//
// Copyright : (C) 2004 Sensoray												//
//////////////////////////////////////////////////////////////////////////////////



// Fundamental types.
#ifdef OS_WINDOWS
// MS Windows specific.
typedef unsigned __int8		u8;							// 8-bit unsigned.
typedef unsigned __int16	u16;						// 16-bit unsigned.
typedef unsigned __int32	u32;						// 32-bit unsigned.
typedef __int16     		s16;						// 16-bit signed.
typedef __int32			    s32;						// 32-bit signed.

#else
// POSIX 1003.1 standard (IEEE Std 1003.1, 1996 Edition).
#include <stdint.h>
typedef uint8_t		        u8;							// 8-bit unsigned.
typedef uint16_t	        u16;						// 16-bit unsigned.
typedef uint32_t	        u32;						// 32-bit unsigned.
typedef int16_t     		s16;						// 16-bit signed.
typedef int32_t 		    s32;						// 32-bit signed.
typedef int			        BOOL;						// Boolean.

#endif

// API types ------------------------------------------------

typedef u32	                HBD;		// Handle to MM.
typedef u32	                GWERR;		// Gateway error flags.
typedef u8	                IOMPORT;	// IOM port number on the MM.
typedef struct XACT_ 		*XACT;		// Pointer to Transaction object.

// Device identifiers ------------------------------------------------------

// Logical devices.
#define LOGDEV_GATEWAY			0x00		// Gateway.
#define LOGDEV_COM1				0x01		// ComPort #1.
#define LOGDEV_COM2				0x02		// ComPort #2.
#define LOGDEV_COM3				0x03		// ComPort #3.
#define LOGDEV_COM4				0x04		// ComPort #4.

// Module identifiers.
#define MODID_GATEWAY			0xFF		// MM gateway.

// Constants for model 2608 analog i/o module ---------------------------------------------------

#define MAX_NUM_AOUTS			8			// Maximum analog output channel count (model 2608-8).

// Analog input types for S26_Sched2608_SetAinTypes().
											// Voltage:
#define RAW_LG_TYPE				0			//   Offset/range corrected ADC (in internal units, +/-32K): 10V scale
#define RAW_HG_TYPE				1			//   Offset/range corrected ADC (in internal units, +/-32K): 0.01V scale
#define V_10_TYPE				2			//   Measured voltage (in Volts): 10V scale
#define V_001_TYPE				3 			//   Measured voltage (in Volts): 0.01V scale
											// Thermocouple: output values are temperatures in degrees C.
#define TC_B_TYPE				4			//   Thermocouple B type.
#define TC_C_TYPE				5			//   Thermocouple C type.
#define TC_E_TYPE				6			//   Thermocouple E type.
#define TC_J_TYPE				7			//   Thermocouple J type.
#define TC_K_TYPE				8			//   Thermocouple K type.
#define TC_N_TYPE				9			//   Thermocouple N type.
#define TC_R_TYPE				10			//   Thermocouple R type.
#define TC_S_TYPE				11			//   Thermocouple S type.
#define TC_T_TYPE				12			//   Thermocouple T type.

// ADC acquisition interval specifiers for S26_Sched2608_GetAins().
#define ADC_SNAPSHOT			0			// Fetch snapshot data that is acquired asynchronously by the 2608 every 2 msec.
#define ADC_INTEGRATED			1			// Fetch integrated data that is acquired asynchronously by the 2608 at the line frequency.

// Line frequency specifiers for S26_Sched2608_SetLineFreq().
#define LINEFREQ_50HZ			1			// Line frequency is 50 Hz.
#define LINEFREQ_60HZ			0			// Line frequency is 60 Hz.

// Constants for model 2612 high-resolution ADC module ---------------------------------------------

#define REF_OUT_1V			    0			// Output reference voltage 1V.
#define REF_OUT_2V			    1			// Output reference voltage 2V.
#define REF_OUT_3V			    2			// Output reference voltage 3V.
#define REF_OUT_5V			    3			// Output reference voltage 5V.

// A/D conversion modes  ---------------------------------------------------------------------------
											// Over Sample Ratio (OSR) / Conversion Rate in 1X mode:
#define OSR_64          0xA0100000			// 64        3.52kHz
#define OSR_128         0xA0200000          // 128       1.76kHz
#define OSR_256         0xA0300000          // 256       880Hz
#define OSR_512         0xA0400000          // 512       440Hz
#define OSR_1024        0xA0500000          // 1024      220Hz
#define OSR_2048        0xA0600000          // 2048      110Hz
#define OSR_4096        0xA0700000          // 4096      55Hz
#define OSR_8192        0xA0800000          // 8192      27.5Hz
#define OSR_16384       0xA0900000          // 16384     13.75Hz
#define OSR_32768       0xA0F00000          // 32768     6.875Hz

#define MODE_2X         0x00080000          // 2X speed mode

// Constants for model 2620 counter module ---------------------------------------

// Soft trigger commands.
#define LOAD_2620				1			// Copy preload register to counter core.
#define LATCH_2620				2			// Transfer counter core to data latch.

// Constants for model 2630 motor controller module -------------------------------

// Output mode register structure.
#define MODE_2620_REVERSE		1			// Reverse bit.
#define MODE_2620_RUN    		2			// Run bit. Reset if 0.

// Serial comport configuration constants -----------------------------------------

// Baud rate clock divisors.
#define SIO_BR_300				0x0300		//    300 bps.
#define SIO_BR_600				0x0180		//    600 bps.
#define SIO_BR_1200				0x00C0		//  1,200 bps.
#define SIO_BR_2400				0x0060		//  2,400 bps.
#define SIO_BR_4800				0x0030		//  4,800 bps.
#define SIO_BR_9600				0x0018		//  9,600 bps.
#define SIO_BR_19200			0x000C		// 19,200 bps.
#define SIO_BR_38400			0x0006		// 38,400 bps.
#define SIO_BR_57600			0x0004		// 57,600 bps.
#define SIO_BR_115200			0x0002		// 115,200 bps.

// Parity types.
#define SIO_PARITY_NONE			0x00		// Parity disabled.
#define SIO_PARITY_ODD			0x08		// Odd parity.
#define SIO_PARITY_EVEN			0x18		// Even parity.

// Character bit counts.
#define SIO_DATA_5				0x00		// 5 data bits.
#define SIO_DATA_6				0x01		// 6 data bits.
#define SIO_DATA_7				0x02		// 7 data bits.
#define SIO_DATA_8				0x03		// 8 data bits.

// Stop bits.
#define SIO_STOP_1				0x00		// 1 stop bit.
#define SIO_STOP_2				0x04		// 2 stop bits (databits>5), or 1.5 stop bits (databits=5).

// Interface type.
#define SIO_PHY_RS232			0x00		// RS-232.
#define SIO_PHY_RS422_IDLEON	0x40		// RS-422, transmitter always enabled.
#define SIO_PHY_RS485			0x80		// RS-485.
#define SIO_PHY_RS422_IDLEOFF	0xC0		// RS-422, transmitter tri-stated when idle.

// Flow control.
#define SIO_FLOW_OFF			0x00		// No flow control.
#define SIO_FLOW_ON				0x20		// XON-XOFF flow control.

// LED events that will cause the comport status LED to light.
#define SIO_LED_TRANSMIT		0x08		// Light upon char transmit.
#define SIO_LED_RECEIVE			0x04		// Light upon char receive.
#define SIO_LED_ERROR			0x02		// Light upon error or break.

// Error codes --------------------------------------------------------------------

// Gateway transactions.
////typedef unsigned long			GWERR;		// Gateway error codes:
#define GWERR_NONE				0x00000000	// No gateway errors detected.
#define GWERR_TOOLARGE			0x00000100	// Too many MCmds in a command packet, or cmd/rsp packet exceeds 1KB.
#define GWERR_XACTALLOC			0x00000300	// Couldn't allocate transaction object.
#define GWERR_IOMNORESPOND		0x00000400	// Bad module response, ModID is in LSB of ErrorCode.
#define GWERR_MMCLOSED			0x00000500	// MM is not open.
#define GWERR_IOMCLOSED			0x00000600	// Iom is not open.
#define GWERR_IOMTYPE			0x00000700	// Action is not supported by the registered iom type.
#define GWERR_IOMERROR			0x00000800	// Iom comm error flag (CERR) is asserted.  See IomStatus[] for details.
#define GWERR_IOMRESET			0x00000900	// Iom reset flag (RST) is asserted.  See IomStatus[] for details.
#define GWERR_MMNORESPOND		0x00000A00	// MM response timed out.
#define GWERR_PACKETSEND		0x00000B00	// Socket driver failed to send command packet.
#define GWERR_IOMSPECIFIC		0x00000C00	// Iom-specific status flag is asserted.  See IomStatus[] for details.
#define GWERR_BADVALUE			0x00000D00	// Illegal argument value (e.g., channel number does not exist).
#define GWERRMASK				0xFFFFFF00	// Mask for gateway error.  Truncates additional info.

// Returned by S26_DriverOpen().
#define DRVERR_NONE				0x00000000	// No errors.
#define DRVERR_MALLOC			0x00000001	// Memory allocation failed.
#define DRVERR_NETWORKOPEN		0x00000002	// Socket library problem (i.e., too many sockets, bad version).
#define DRVERR_CRITICALSECTION	0x00000003	// Can't create critical section.

// Returned by S26_BoardOpen().
#define ERR_NONE				0x00000000	// No errors.
#define ERR_BADHANDLE			0x00000001	// Illegal MM handle.
#define ERR_CREATESOCKET		0x00000002	// Can't create socket.
#define ERR_BINDSOCKET			0x00000004	// Can't bind socket to NIC.

// IOM status bits ----------------------------------------------------------------

// Common to all iom types.
#define STATUS_RST				0x80		// Module reset flag.
#define STATUS_CERR				0x40		// Communication error detected.

// Iom type-specific.
#define STATUS_2608_CALERR		0x10		// 2608: Calibration values out of tolerance, defaults applied.
#define STATUS_2610_STRM		0x01		// 2610: Serial control stream error.
#define STATUS_2612_OVERFLOW	0x01		// 2612: Out of range (positive).
#define STATUS_2612_UNDERFLOW	0x02		// 2612: Out of range (negative).
#define STATUS_2612_TIMEOUT		0x04		// 2612: ADC not ready.
#define STATUS_2612_EEPROM		0x08		// 2612: EEPROM read/write error.
#define STATUS_2650_DRVR		0x02		// 2650: Relay coil driver fault.
#define STATUS_2650_STRM		0x01		// 2650: Serial control stream error.
#define STATUS_2652_STRM		0x01		// 2652: Serial control stream error.

// Serial comport status bits -----------------------------------------------------

#define COM_REJECTED			0x80		// Command rejected by the MM.
#define COM_FRAMINGERROR		0x08		// Framing error detected.
#define COM_PARITYERROR			0x04		// Parity error detected.
#define COM_OVERFLOWERROR		0x02		// UART or receive buffer overflowed.
#define COM_ISOPEN				0x01		// Comport is open.
